@@ -1609,6 +1609,8 @@ ags_sfz_synth_connect(AgsConnectable *connectable)
   g_signal_connect_after(sfz_synth->chorus_delay, "value-changed",
 			 G_CALLBACK(ags_sfz_synth_chorus_delay_callback), sfz_synth);
 
+  g_signal_connect_after(sfz_synth->tremolo_enabled, "clicked",
+			 G_CALLBACK(ags_sfz_synth_tremolo_enabled_callback), sfz_synth);
 
   g_signal_connect_after(sfz_synth->tremolo_lfo_depth, "value-changed",
 			 G_CALLBACK(ags_sfz_synth_tremolo_lfo_depth_callback), sfz_synth);
@@ -1619,6 +1621,9 @@ ags_sfz_synth_connect(AgsConnectable *connectable)
   g_signal_connect_after(sfz_synth->tremolo_tuning, "value-changed",
 			 G_CALLBACK(ags_sfz_synth_tremolo_tuning_callback), sfz_synth);
 
+  g_signal_connect_after(sfz_synth->vibrato_enabled, "clicked",
+			 G_CALLBACK(ags_sfz_synth_vibrato_enabled_callback), sfz_synth);
+
   g_signal_connect_after(sfz_synth->vibrato_gain, "value-changed",
 			 G_CALLBACK(ags_sfz_synth_vibrato_gain_callback), sfz_synth);
 
@@ -1631,6 +1636,12 @@ ags_sfz_synth_connect(AgsConnectable *connectable)
   g_signal_connect_after(sfz_synth->vibrato_tuning, "value-changed",
 			 G_CALLBACK(ags_sfz_synth_vibrato_tuning_callback), sfz_synth);
 
+  g_signal_connect_after(sfz_synth->wah_wah_enabled, "clicked",
+			 G_CALLBACK(ags_sfz_synth_wah_wah_enabled_callback), sfz_synth);
+
+  g_signal_connect_after(sfz_synth->wah_wah_length, "changed",
+			 G_CALLBACK(ags_sfz_synth_wah_wah_length_callback), sfz_synth);
+  
   g_signal_connect_after(sfz_synth->wah_wah_attack_x, "value-changed",
 			 G_CALLBACK(ags_sfz_synth_wah_wah_attack_callback), sfz_synth);
 
@@ -1754,6 +1765,12 @@ ags_sfz_synth_disconnect(AgsConnectable *connectable)
 		      (gpointer) sfz_synth,
 		      NULL);
 
+  g_object_disconnect((GObject *) sfz_synth->tremolo_enabled,
+		      "any_signal::clicked",
+		      G_CALLBACK(ags_sfz_synth_tremolo_enabled_callback),
+		      sfz_synth,
+		      NULL);
+
   g_object_disconnect((GObject *) sfz_synth->tremolo_gain,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_tremolo_gain_callback),
@@ -1778,6 +1795,12 @@ ags_sfz_synth_disconnect(AgsConnectable *connectable)
 		      (gpointer) sfz_synth,
 		      NULL);
 
+  g_object_disconnect((GObject *) sfz_synth->vibrato_enabled,
+		      "any_signal::clicked",
+		      G_CALLBACK(ags_sfz_synth_vibrato_enabled_callback),
+		      sfz_synth,
+		      NULL);
+
   g_object_disconnect((GObject *) sfz_synth->vibrato_gain,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_vibrato_gain_callback),
@@ -1796,55 +1819,67 @@ ags_sfz_synth_disconnect(AgsConnectable *connectable)
 		      (gpointer) sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_attack_x,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_enabled,
+		      "any_signal::clicked",
+		      G_CALLBACK(ags_sfz_synth_wah_wah_enabled_callback),
+		      sfz_synth,
+		      NULL);
+
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_length,
+		      "any_signal::changed",
+		      G_CALLBACK(ags_sfz_synth_wah_wah_length_callback),
+		      sfz_synth,
+		      NULL);
+
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_attack_x,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_attack_callback),
 		      sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_attack_y,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_attack_y,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_attack_callback),
 		      sfz_synth,
 		      NULL);
   
-  g_object_disconnect(sfz_synth->wah_wah_decay_x,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_decay_x,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_decay_callback),
 		      sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_decay_y,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_decay_y,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_decay_callback),
 		      sfz_synth,
 		      NULL);
   
-  g_object_disconnect(sfz_synth->wah_wah_sustain_x,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_sustain_x,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_sustain_callback),
 		      sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_sustain_y,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_sustain_y,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_sustain_callback),
 		      sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_release_x,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_release_x,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_release_callback),
 		      sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_release_y,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_release_y,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_release_callback),
 		      sfz_synth,
 		      NULL);
 
-  g_object_disconnect(sfz_synth->wah_wah_ratio,
+  g_object_disconnect((GObject *) sfz_synth->wah_wah_ratio,
 		      "any_signal::value-changed",
 		      G_CALLBACK(ags_sfz_synth_wah_wah_ratio_callback),
 		      sfz_synth,
